import SwiftUI

/// JHCalendar
public struct JHCalendar<DayContent : View>: View {
    @Environment(\.calendarHeight) var calendarHeight
    @Environment(\.calendarShowTitle) var showTitle
    
    @EnvironmentObject var manager : CalendarManger
    
    var content : ((CalendarComponent) -> DayContent)
    
    var weekbarHeight : CGFloat
    var titleHeight : CGFloat
    
    /// JHCalendar
    /// - Parameter titleHeight : Calendar title height.
    /// - Parameter weekbarHeight : Claendar weekday bar height.
    /// - Parameter content : Custom Day view. If you don't want to customize Day view, use DefaultCalendarDayView.
    public init(titleHeight : CGFloat = 45,weekbarHeight : CGFloat = 40,@ViewBuilder content : @escaping (CalendarComponent) -> DayContent ){
        self.content = content
        self.weekbarHeight = weekbarHeight
        self.titleHeight = titleHeight
    }
    
    public var body: some View {
        VStack(spacing:0){
            if showTitle {
                CalendarTitle()
                    .frame(height:titleHeight)
            }
            WeekBar().frame(height:weekbarHeight)
            if manager.calendarMode == .Month {
                TabView(selection: $manager.currentPage){
                    ForEach(manager.generateMonthComponents()){ component in
                        JHMonthView(page: component.data, content: { day in
                            content(day)
                        }).tag(component.tag)
                    }
                }.tabViewStyle(.page(indexDisplayMode: .never))
                    .frame(height: calendarHeight * 6)
                    .transition(AnyTransition.identity)
            } else {
                TabView(selection: $manager.currentPage){
                    ForEach(manager.generateWeekComponents()){ component in
                        JHWeekView(data: component){ day in
                            content(day)
                        }.tag(component.tag)
                    }
                }
                .transition(AnyTransition.identity)
                .tabViewStyle(.page(indexDisplayMode: .never))
                .frame(height: calendarHeight)
            }
        }
    }
}

struct JHCalendar_Previews: PreviewProvider {
    static var previews: some View {
        JHCalendar(weekbarHeight:40,content: {
            DefaultCalendarDayView(component: $0)
        })
        .environmentObject(CalendarManger(start: .startDefault, end: .endDefault, point: .currentDefault))
    }
}
